[![Build Status](https://travis-ci.org/simonsobs/acondbs.svg?branch=master)](https://travis-ci.org/simonsobs/acondbs) [![codecov](https://codecov.io/gh/simonsobs/acondbs/branch/master/graph/badge.svg)](https://codecov.io/gh/simonsobs/acondbs)

# Acondbs

A GraphQL server for product DB